# Generated by roxygen2: do not edit by hand

export("%>%")
export(callRelatedness)
export(get_column_new)
export(plotDOUGH)
export(plotLOAF)
export(plotSLICE)
export(priorSensitivity)
export(processEigenstrat)
export(processEigenstrat_old)
export(read_ind)
export(read_snp)
export(saveSLICES)
export(sim_geno)
export(split_line)
export(test_degree)
import(data.table)
importFrom(magrittr,"%>%")
