#' counts_example
#'
#' this is an example of the tibble made by processEigenstrat().
#'
#' @format ## `counts_example`
#' A data frame with 15 rows and 4 columns:
#' \describe{
#' \item{pair}{the pair of individuals that are compared}
#' \item{nsnps}{the number of overlapping snps that were compared for each pair.}
#' \item{mismatch}{the number of sites which did not match for each pair.}
#' \item{pmr}{the pairwise mismatch rate (mismatch/nsnps).}
#' }
"counts_example"
